@@ -9,7 +9,7 @@
 
 package Glib::GenPod;
 
-our $VERSION = '0.03';
+our $VERSION = '1.304';
 
 use strict;
 use warnings;
@@ -1216,7 +1216,7 @@ sub convert_type {
 	              \s*$/x;				# trailing space
 	my $ctype   = $1 || '!!';
 	if ($ctype eq '!!') {
-		warn "Glib::GenPod: Unable to parse type `$typestr´";
+		warn "Glib::GenPod: Unable to parse type '$typestr'";
 	}
 
 	# variant type
@@ -1539,10 +1539,10 @@ mcfarland hacked this module together via irc and email over the next few days.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2004, 2010, 2011 by the gtk2-perl team
+Copyright (C) 2003-2004, 2010-2013 by the gtk2-perl team
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of the Lesser General Public License (LGPL).  For 
+it under the terms of the Lesser General Public License (LGPL).  For
 more information, see http://www.fsf.org/licenses/lgpl.txt
 
 =cut
